@@ -2,7 +2,7 @@ module Main where
 
 import GHC.Driver.Env
 import GHC.Driver.Session
-  (getDynFlags, parseDynamicFlagsCmdLine, defaultFatalMessager, defaultFlushOut)
+  (extractDynFlags, parseDynamicFlagsCmdLine, defaultFatalMessager, defaultFlushOut)
 import GHC.Driver.Plugins
 import GHC.Driver.Monad
 
@@ -65,10 +65,12 @@ main = do
       GHC.setTargets []
       _ <- GHC.load LoadAllTargets
 
-      target <- guessTarget "static-plugins-module.hs" Nothing
+      target <- guessTarget "static-plugins-module.hs" Nothing Nothing
       setTargets [target]
 
-      modifySession (\hsc_env -> hsc_env { hsc_static_plugins = the_plugins})
+      modifySession $ \hsc_env ->
+        let old_plugins = hsc_plugins hsc_env
+        in hsc_env { hsc_plugins = old_plugins { staticPlugins = the_plugins } }
 
       dflags <- getSessionDynFlags
       setSessionDynFlags dflags { outputFile_ = Nothing }
