@@ -1,5 +1,3 @@
-{-# LANGUAGE KindSignatures #-}
-
 module WCompatWarningsOnOff where
 
 import qualified Data.Semigroup as Semi
@@ -15,7 +13,3 @@ instance Semi.Semigroup S where
 instance Monoid S where
   S a `mappend` S b = S (a+b)
   mempty = S 0
-
--- -fwarn-star-is-type
-b :: (Bool :: *)
-b = True
